with
  text_io,
  ada.integer_text_io,
  ada.long_float_text_io;

use
  text_io,
  ada.integer_text_io,
  ada.long_float_text_io;

procedure square is

  type imat2 is array (integer range <>, integer range <>) of integer;

  type imat2_ptr is access imat2;

  maxls,maxminor,maxlist,maxmajor : integer;
  n,nn,ne,nk                      : integer;
  lstol,mntol,mnref               : long_float;
  a,da,young,poisson,pressure     : long_float;
  node                            : imat2_ptr;

  procedure scan (io : in text_io.file_type) is

    ascii : character;

  begin
    loop
      text_io.get(io,ascii);
      text_io.skip_line(io);
      exit when ascii = ':';
    end loop;
  end scan;

  procedure initia is

    use
      text_io,
      ada.integer_text_io,
      ada.long_float_text_io;

    i,j,s : integer;
    io    : file_type;

  begin
    open(io, in_file, "square.txt");

    scan(io);
    get(io,n);
    get(io,a);
    skip_line(io);

    -- young   : Young's modulus, multiplied by thickness
    -- poisson : Poissons ratio

    scan(io);
    get(io,young);
    get(io,poisson);
    skip_line(io);

    scan(io);
    get(io,pressure);
    skip_line(io);

    close(io);

    -- initiate nn, ne, nk, da
    nn := 2 * n * (n + 1) + 1;
    ne := 4 * n * n;
    nk := 12 * n;
    da := a / long_float(n);

    -- solution parameters
    lstol := 0.1;
    maxls := 20;
    mntol := 0.001;
    mnref := 0.0;
    maxminor := 30 * nn;
    maxlist := 3;
    maxmajor := 20;

    -- nodes
    node := new imat2 (-n .. n, -n .. n);
    for i in -n .. n loop
      for j in -n .. n loop
        node(i,j) := 0;
      end loop;
    end loop;

    s := 0;
    j := -n;
    loop
      i := -n;
      loop
        s := s + 1;
        node(i,j) := s;

        exit when i = n;
        i := i + 2;
      end loop;

      s := s + n;

      exit when j = n;
      j := j + 2;
    end loop;

    s := n + 1;
    j := -n + 1;
    loop
      i := -n + 1;
      loop
        s := s + 1;
        node(i,j) := s;

        exit when i = n - 1;
        i := i + 2;
      end loop;

      s := s + n + 1;

      exit when j = n - 1;
      j := j + 2;
    end loop;
  end initia;

  procedure input is

    use
      text_io,
      ada.integer_text_io,
      ada.long_float_text_io;

    i,j,imax,jmax,e : integer;
    x,y             : long_float;
    io              : file_type;

  begin
    create(io, out_file, "input.txt");

    put(io,"        lstol     maxls             mntol             mnref  maxminor   maxlist  maxmajor");
    new_line(io);
    put(io,":");
    new_line(io);
    put(io,lstol,2,6,3);
    put(io,"     ");
    put(io,maxls,5);
    put(io,"     ");
    put(io,mntol,2,6,3);
    put(io,"     ");
    put(io,mnref,2,6,3);
    put(io,"     ");
    put(io,maxminor,5);
    put(io,"     ");
    put(io,maxlist,5);
    put(io,"     ");
    put(io,maxmajor,5);
    new_line(io);

    -- young, poisson, density
    new_line(io);
    new_line(io);
    put(io,"        young           poisson           density");
    new_line(io);
    put(io,":");
    new_line(io);
    put(io,young,2,6,3);
    put(io,"     ");
    put(io,poisson,2,6,3);
    put(io,"      0.000000E+00");
    new_line(io);

    -- node coordinates
    new_line(io);
    new_line(io);
    put(io," node           coord x           coord y           coord z");
    new_line(io);
    put(io,":");
    new_line(io);
    put(io,nn,5);
    new_line(io);

    new_line(io);

    for j in -n .. n loop
      for i in -n .. n loop
        if node(i,j) > 0 then
          x := long_float(i) * da;
          y := long_float(j) * da;
          put(io,node(i,j),5);
          put(io,"     ");
          put(io,x,2,6,3);
          put(io,"     ");
          put(io,y,2,6,3);
          put(io,"      0.000000E+00");
          new_line(io);
        end if;
      end loop;
    end loop;

    -- membrane elements
    new_line(io);
    new_line(io);
    put(io," elem      node      node      node");
    new_line(io);
    put(io,":");
    new_line(io);
    put(io,ne,5);
    new_line(io);

    e := 0;
    new_line(io);

    -- x direction
    for i in reverse -(n - 1) .. 0 loop
      j := i;
      jmax := -j;
      loop
        e := e + 1;
        put(io,e,5);
        put(io,"     ");
        put(io,node(i,j),5);
        put(io,"     ");
        put(io,node(i - 1,j + 1),5);
        put(io,"     ");
        put(io,node(i - 1,j - 1),5);
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    for i in reverse -n .. -2 loop
      j := i + 2;
      jmax := -j;
      loop
        e := e + 1;
        put(io,e,5);
        put(io,"     ");
        put(io,node(i,j),5);
        put(io,"     ");
        put(io,node(i + 1,j - 1),5);
        put(io,"     ");
        put(io,node(i + 1,j + 1),5);
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    for i in 0 .. (n - 1) loop
      j := -i;
      jmax := -j;
      loop
        e := e + 1;
        put(io,e,5);
        put(io,"     ");
        put(io,node(i,j),5);
        put(io,"     ");
        put(io,node(i + 1,j - 1),5);
        put(io,"     ");
        put(io,node(i + 1,j + 1),5);
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    for i in 2 .. n loop
      j := -i + 2;
      jmax := -j;
      loop
        e := e + 1;
        put(io,e,5);
        put(io,"     ");
        put(io,node(i,j),5);
        put(io,"     ");
        put(io,node(i - 1,j + 1),5);
        put(io,"     ");
        put(io,node(i - 1,j - 1),5);
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    -- y direction
    for j in reverse -(n - 1) .. 0 loop
      i := j;
      imax := -i;
      loop
        e := e + 1;
        put(io,e,5);
        put(io,"     ");
        put(io,node(i,j),5);
        put(io,"     ");
        put(io,node(i - 1,j - 1),5);
        put(io,"     ");
        put(io,node(i + 1,j - 1),5);
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    for j in reverse -n .. -2 loop
      i := j + 2;
      imax := -i;
      loop
        e := e + 1;
        put(io,e,5);
        put(io,"     ");
        put(io,node(i,j),5);
        put(io,"     ");
        put(io,node(i + 1,j + 1),5);
        put(io,"     ");
        put(io,node(i - 1,j + 1),5);
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    for j in 0 .. (n - 1) loop
      i := -j;
      imax := -i;
      loop
        e := e + 1;
        put(io,e,5);
        put(io,"     ");
        put(io,node(i,j),5);
        put(io,"     ");
        put(io,node(i + 1,j + 1),5);
        put(io,"     ");
        put(io,node(i - 1,j + 1),5);
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    for j in 2 .. n loop
      i := -j + 2;
      imax := -i;
      loop
        e := e + 1;
        put(io,e,5);
        put(io,"     ");
        put(io,node(i,j),5);
        put(io,"     ");
        put(io,node(i - 1,j - 1),5);
        put(io,"     ");
        put(io,node(i + 1,j - 1),5);
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    -- known displacements
    new_line(io);
    new_line(io);
    put(io," node      axis             displ");
    new_line(io);
    put(io,":");
    new_line(io);
    put(io,nk,5);
    new_line(io);

    new_line(io);

    -- corner
    for axis in 1 .. 3 loop
      put(io,node(-n,-n),5);
      put(io,"     ");
      put(io,axis,5);
      put(io,"      0.000000E+00");
      new_line(io);
    end loop;

    for axis in 1 .. 3 loop
      put(io,node(n,-n),5);
      put(io,"     ");
      put(io,axis,5);
      put(io,"      0.000000E+00");
      new_line(io);
    end loop;

    for axis in 1 .. 3 loop
      put(io,node(-n,n),5);
      put(io,"     ");
      put(io,axis,5);
      put(io,"      0.000000E+00");
      new_line(io);
    end loop;

    for axis in 1 .. 3 loop
      put(io,node(n,n),5);
      put(io,"     ");
      put(io,axis,5);
      put(io,"      0.000000E+00");
      new_line(io);
    end loop;

    -- x direction
    i := -n + 2;
    loop
      for axis in 1 .. 3 loop
        put(io,node(i,-n),5);
        put(io,"     ");
        put(io,axis,5);
        put(io,"      0.000000E+00");
        new_line(io);
      end loop;

      for axis in 1 .. 3 loop
        put(io,node(i,n),5);
        put(io,"     ");
        put(io,axis,5);
        put(io,"      0.000000E+00");
        new_line(io);
      end loop;

      exit when i = n - 2;
      i := i + 2;
    end loop;

    -- y direction
    j := -n + 2;
    loop
      for axis in 1 .. 3 loop
        put(io,node(-n,j),5);
        put(io,"     ");
        put(io,axis,5);
        put(io,"      0.000000E+00");
        new_line(io);
      end loop;

      for axis in 1 .. 3 loop
        put(io,node(n,j),5);
        put(io,"     ");
        put(io,axis,5);
        put(io,"      0.000000E+00");
        new_line(io);
      end loop;

      exit when j = n - 2;
      j := j + 2;
    end loop;

    -- nodal actions
    new_line(io);
    new_line(io);
    put(io," node      axis            action");
    new_line(io);
    put(io,":");
    new_line(io);
    put(io,"    0");
    new_line(io);

    -- pressure
    new_line(io);
    new_line(io);
    put(io," elem          pressure");
    new_line(io);
    put(io,":");
    new_line(io);
    put(io,ne,5);
    new_line(io);

    new_line(io);
    for e in 1 .. ne loop
      put(io,e,5);
      put(io,"     ");
      put(io,pressure,2,6,3);
      new_line(io);
    end loop;

    close(io);
  end input;

  procedure autocad is

    use
      text_io,
      ada.long_float_text_io;

    i,j,imax,jmax : integer;
    x,y           : long_float;
    io            : file_type;

  begin
    create(io, out_file, "autocad.scr");

    -- set running object snap mode to NONE
    put(io,"osmode 0");
    new_line(io);

    -- surface
    put(io,"layer make surface ");
    new_line(io);

    -- x direction
    for i in reverse -(n - 1) .. 0 loop
      j := i;
      jmax := -j;
      loop
        put(io,"3dface ");

        x := long_float(i) * da;
        y := long_float(j) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i - 1) * da;
        y := long_float(j + 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i - 1) * da;
        y := long_float(j - 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        put(io," ");
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    for i in reverse -n .. -2 loop
      j := i + 2;
      jmax := -j;
      loop
        put(io,"3dface ");

        x := long_float(i) * da;
        y := long_float(j) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i + 1) * da;
        y := long_float(j - 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i + 1) * da;
        y := long_float(j + 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        put(io," ");
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    for i in 0 .. (n - 1) loop
      j := -i;
      jmax := -j;
      loop
        put(io,"3dface ");

        x := long_float(i) * da;
        y := long_float(j) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i + 1) * da;
        y := long_float(j - 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i + 1) * da;
        y := long_float(j + 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        put(io," ");
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    for i in 2 .. n loop
      j := -i + 2;
      jmax := -j;
      loop
        put(io,"3dface ");

        x := long_float(i) * da;
        y := long_float(j) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i - 1) * da;
        y := long_float(j + 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i - 1) * da;
        y := long_float(j - 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        put(io," ");
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    -- y direction
    for j in reverse -(n - 1) .. 0 loop
      i := j;
      imax := -i;
      loop
        put(io,"3dface ");

        x := long_float(i) * da;
        y := long_float(j) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i - 1) * da;
        y := long_float(j - 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i + 1) * da;
        y := long_float(j - 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        put(io," ");
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    for j in reverse -n .. -2 loop
      i := j + 2;
      imax := -i;
      loop
        put(io,"3dface ");

        x := long_float(i) * da;
        y := long_float(j) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i + 1) * da;
        y := long_float(j + 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i - 1) * da;
        y := long_float(j + 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        put(io," ");
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    for j in 0 .. (n - 1) loop
      i := -j;
      imax := -i;
      loop
        put(io,"3dface ");

        x := long_float(i) * da;
        y := long_float(j) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i + 1) * da;
        y := long_float(j + 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i - 1) * da;
        y := long_float(j + 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        put(io," ");
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    for j in 2 .. n loop
      i := -j + 2;
      imax := -i;
      loop
        put(io,"3dface ");

        x := long_float(i) * da;
        y := long_float(j) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i - 1) * da;
        y := long_float(j - 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        x := long_float(i + 1) * da;
        y := long_float(j - 1) * da;
        put(io,x,1,6,3);
        put(io,",");
        put(io,y,1,6,3);
        put(io,",");
        put(io,"0.000000E+00");
        put(io," ");

        put(io," ");
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    put(io,"layer set 0 ");
    new_line(io);

    put(io,"zoom ext ext");
    new_line(io);

    close(io);
  end autocad;

  procedure ansys is

    use
      text_io,
      ada.integer_text_io,
      ada.long_float_text_io;

    i,j,imax,jmax,e : integer;
    x,y             : long_float;
    io              : file_type;

  begin
    create(io, out_file, "ansys.txt");

    put(io,"! ENTER THE MODEL CREATION PREPROCESSOR");
    new_line(io);
    put(io,"/PREP7");
    new_line(io);

    new_line(io);
    put(io,"! ---------------------------------------");
    new_line(io);

    -- define material property
    new_line(io);
    put(io,"! DEFINE MATERIAL PROPERTY");
    new_line(io);

    put(io,"MP,   EX, 1, ");
    put(io,young,2,6,3);
    new_line(io);

    put(io,"MP, PRXY, 1, ");
    put(io,poisson,2,6,3);
    new_line(io);

    put(io,"MP, ALPX, 1,  1.000000E+00");
    new_line(io);

    new_line(io);
    put(io,"! ---------------------------------------");
    new_line(io);

    -- define nodes
    new_line(io);
    put(io,"! DEFINE NODES");
    new_line(io);

    put(io,"N,     1,  0.000000E+00,  0.000000E+00,  0.000000E+00");
    new_line(io);
    for j in -n .. n loop
      for i in -n .. n loop
        if node(i,j) > 0 then
          x := long_float(i) * da;
          y := long_float(j) * da;
          put(io,"N, ");
          put(io,node(i,j),5);
          put(io,", ");
          put(io,x,2,6,3);
          put(io,", ");
          put(io,y,2,6,3);
          put(io,",  0.000000E+00");
          new_line(io);
        end if;
      end loop;
    end loop;

    new_line(io);
    put(io,"! ---------------------------------------");
    new_line(io);

    -- define element type
    new_line(io);
    put(io,"! DEFINE ELEMENT TYPE");
    new_line(io);
    put(io,"ET, 1, SHELL41");
    new_line(io);

    -- define element real constants
    new_line(io);
    put(io,"! DEFINE ELEMENT REAL CONSTANTS");
    new_line(io);
    put(io,"R, 1, 1.0");
    new_line(io);

    -- define elements
    new_line(io);
    put(io,"! DEFINE ELEMENTS");
    new_line(io);

    e := 0;

    -- x direction
    for i in reverse -(n - 1) .. 0 loop
      j := i;
      jmax := -j;
      loop
        e := e + 1;
        put(io,"EN, ");
        put(io,e,5);
        put(io,", ");
        put(io,node(i,j),5);
        put(io,", ");
        put(io,node(i - 1,j + 1),5);
        put(io,", ");
        put(io,node(i - 1,j - 1),5);
        put(io,", ");
        put(io,node(i - 1,j - 1),5);
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    for i in reverse -n .. -2 loop
      j := i + 2;
      jmax := -j;
      loop
        e := e + 1;
        put(io,"EN, ");
        put(io,e,5);
        put(io,", ");
        put(io,node(i,j),5);
        put(io,", ");
        put(io,node(i + 1,j - 1),5);
        put(io,", ");
        put(io,node(i + 1,j + 1),5);
        put(io,", ");
        put(io,node(i + 1,j + 1),5);
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    for i in 0 .. (n - 1) loop
      j := -i;
      jmax := -j;
      loop
        e := e + 1;
        put(io,"EN, ");
        put(io,e,5);
        put(io,", ");
        put(io,node(i,j),5);
        put(io,", ");
        put(io,node(i + 1,j - 1),5);
        put(io,", ");
        put(io,node(i + 1,j + 1),5);
        put(io,", ");
        put(io,node(i + 1,j + 1),5);
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    for i in 2 .. n loop
      j := -i + 2;
      jmax := -j;
      loop
        e := e + 1;
        put(io,"EN, ");
        put(io,e,5);
        put(io,", ");
        put(io,node(i,j),5);
        put(io,", ");
        put(io,node(i - 1,j + 1),5);
        put(io,", ");
        put(io,node(i - 1,j - 1),5);
        put(io,", ");
        put(io,node(i - 1,j - 1),5);
        new_line(io);

        exit when j = jmax;
        j := j + 2;
      end loop;
    end loop;

    -- y direction
    for j in reverse -(n - 1) .. 0 loop
      i := j;
      imax := -i;
      loop
        e := e + 1;
        put(io,"EN, ");
        put(io,e,5);
        put(io,", ");
        put(io,node(i,j),5);
        put(io,", ");
        put(io,node(i - 1,j - 1),5);
        put(io,", ");
        put(io,node(i + 1,j - 1),5);
        put(io,", ");
        put(io,node(i + 1,j - 1),5);
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    for j in reverse -n .. -2 loop
      i := j + 2;
      imax := -i;
      loop
        e := e + 1;
        put(io,"EN, ");
        put(io,e,5);
        put(io,", ");
        put(io,node(i,j),5);
        put(io,", ");
        put(io,node(i + 1,j + 1),5);
        put(io,", ");
        put(io,node(i - 1,j + 1),5);
        put(io,", ");
        put(io,node(i - 1,j + 1),5);
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    for j in 0 .. (n - 1) loop
      i := -j;
      imax := -i;
      loop
        e := e + 1;
        put(io,"EN, ");
        put(io,e,5);
        put(io,", ");
        put(io,node(i,j),5);
        put(io,", ");
        put(io,node(i + 1,j + 1),5);
        put(io,", ");
        put(io,node(i - 1,j + 1),5);
        put(io,", ");
        put(io,node(i - 1,j + 1),5);
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    for j in 2 .. n loop
      i := -j + 2;
      imax := -i;
      loop
        e := e + 1;
        put(io,"EN, ");
        put(io,e,5);
        put(io,", ");
        put(io,node(i,j),5);
        put(io,", ");
        put(io,node(i - 1,j - 1),5);
        put(io,", ");
        put(io,node(i + 1,j - 1),5);
        put(io,", ");
        put(io,node(i + 1,j - 1),5);
        new_line(io);

        exit when i = imax;
        i := i + 2;
      end loop;
    end loop;

    new_line(io);
    put(io,"! ---------------------------------------");
    new_line(io);

    -- include large deformation effects
    new_line(io);
    put(io,"! INCLUDE LARGE DEFORMATION EFFECTS");
    new_line(io);
    put(io,"NLGEOM, ON");
    new_line(io);

    new_line(io);
    put(io,"! ---------------------------------------");
    new_line(io);

    -- set convergence values for nonlinear analysis
    new_line(io);
    put(io,"! SET CONVERGENCE VALUES FOR NONLINEAR ANALYSIS");
    new_line(io);
    put(io,"CNVTOL, F, , ");
    put(io,mntol,2,6,3);
    put(io,", 0, -1.0");
    new_line(io);

    new_line(io);
    put(io,"FINISH");
    new_line(io);

    new_line(io);
    put(io,"! ---------------------------------------");
    new_line(io);

    new_line(io);
    put(io,"! ENTER THE SOLUTION PROCESSOR");
    new_line(io);
    put(io,"/SOLU");
    new_line(io);

    new_line(io);
    put(io,"! ---------------------------------------");
    new_line(io);

    new_line(io);
    put(io,"! DEFINE DOF CONSTRAINTS");
    new_line(io);
    put(io,"D, ALL, ALL");
    new_line(io);

    new_line(io);
    put(io,"! ASSIGN A UNIFORM TEMPERATURE TO ALL NODES");
    new_line(io);
    put(io,"TUNIF, -1.000000E-03");
    new_line(io);

    new_line(io);
    put(io,"! START SOLUTION");
    new_line(io);
    put(io,"SOLVE");
    new_line(io);

    new_line(io);
    put(io,"! ---------------------------------------");
    new_line(io);

    -- known displacements
    new_line(io);
    put(io,"! DELETE DOF CONSTRAINTS");
    new_line(io);
    put(io,"DDELE, ALL, ALL");
    new_line(io);

    new_line(io);
    put(io,"! DEFINE DOF CONSTRAINTS");
    new_line(io);

    -- corner
    put(io,"D, ");
    put(io,node(-n,-n),5);
    put(io,", ALL,  0.000000E+00");
    new_line(io);

    put(io,"D, ");
    put(io,node(n,-n),5);
    put(io,", ALL,  0.000000E+00");
    new_line(io);

    put(io,"D, ");
    put(io,node(-n,n),5);
    put(io,", ALL,  0.000000E+00");
    new_line(io);

    put(io,"D, ");
    put(io,node(n,n),5);
    put(io,", ALL,  0.000000E+00");
    new_line(io);

    -- x direction
    i := -n + 2;
    loop
      put(io,"D, ");
      put(io,node(i,-n),5);
      put(io,", ALL,  0.000000E+00");
      new_line(io);

      put(io,"D, ");
      put(io,node(i,n),5);
      put(io,", ALL,  0.000000E+00");
      new_line(io);

      exit when i = n - 2;
      i := i + 2;
    end loop;

    -- y direction
    j := -n + 2;
    loop
      put(io,"D, ");
      put(io,node(-n,j),5);
      put(io,", ALL,  0.000000E+00");
      new_line(io);

      put(io,"D, ");
      put(io,node(n,j),5);
      put(io,", ALL,  0.000000E+00");
      new_line(io);

      exit when j = n - 2;
      j := j + 2;
    end loop;

    -- specify surface loads on elements
    new_line(io);
    put(io,"! SPECIFY SURFACE LOADS ON ELEMENTS");
    new_line(io);
    put(io,"SFE, ALL, 1, PRES, 0, ");
    put(io,pressure,2,6,3);
    new_line(io);

    new_line(io);
    put(io,"! START SOLUTION");
    new_line(io);
    put(io,"SOLVE");
    new_line(io);

    new_line(io);
    put(io,"FINISH");
    new_line(io);

    close(io);
  end ansys;

begin
  initia;
  input;
  autocad;
  ansys;
end square;
